@@ -62,12 +62,13 @@
 #' grid.draw(pd.plot)
 #' dev.off()
 #' # Partial dependence plot for metafor rma() model:
+#' data("dat.bcg", package = "metadat")
 #' dat <- escalc(measure="RR", ai=tpos, bi=tneg, ci=cpos, di=cneg, data=dat.bcg)
 #' dat$yi <- as.numeric(dat$yi)
 #' dat$alloc <- factor(dat$alloc)
 #' dat$ablat_d <- cut(dat$ablat, breaks = 2, labels = c("low", "high"))
 #' # Demonstrate partial dependence plot for a bivariate plot_int
-#' rma.model.int <- rma(yi, vi, mods=cbind(ablat, tpos),
+#' rma.model.int <- metafor::rma(yi, vi, mods=cbind(ablat, tpos),
 #'                      data=dat, method="REML")
 #' PartialDependence(rma.model.int, rawdata = TRUE, pi = .95,
 #'                   plot_int = TRUE)
@@ -77,7 +78,7 @@
 #' dat2[3:7] <- lapply(dat2[3:7],
 #'                     function(x){as.numeric(scale(x, scale = FALSE))})
 #' mf.model.all <- MetaForest(yi ~ ., dat2[, c(3:11)])
-#' rma.model.all <- rma(dat$yi, dat2$vi,
+#' rma.model.all <- metafor::rma(dat$yi, dat2$vi,
 #'                   mods = model.matrix(yi~., dat2[, c(3:10)])[, -1],
 #'                   method="REML")
 #' PartialDependence(mf.model.all, rawdata = TRUE, pi = .95)
@@ -141,7 +142,7 @@ PartialDependence.MetaForest <-
            ...) {
     all_args <- as.list(match.call()[-1])
     # Check input arguments ---------------------------------------------------
-    if(hasArg("label_elements")){
+    if(methods::hasArg("label_elements")){
       label_elements <- eval(match.call()[["label_elements"]])
     } else {
       label_elements <- NULL
@@ -230,7 +231,7 @@ PartialDependence.MetaForest <-
     # Process raw data --------------------------------------------------------
 
     cont_mod <- FALSE
-    raw.data <- data.table(x$data, wi = x$weights)
+    raw.data <- data.table::data.table(x$data, wi = x$weights)
     setcolorder(raw.data, c(names(raw.data)[!names(raw.data) %in% x$forest$forest$independent.variable.names],
                             x$forest$forest$independent.variable.names
                             ))
@@ -328,9 +329,9 @@ create_plotlist <-
       if (plot_int) {
         if (cont_mod) {
           # Heatmap
-          p <- ggplot(.plot, aes_string(
-            x = names(.plot)[1],
-            y = names(.plot)[2],
+          p <- ggplot(.plot, aes(
+            x = .data[[names(.plot)[1]]],
+            y = .data[[names(.plot)[2]]],
             fill = "preds"
           )) +
             geom_raster() +
@@ -355,12 +356,12 @@ create_plotlist <-
           if (bw) {
             p <- ggplot(
               .plot,
-              aes_string(
-                x = names(.plot)[1],
-                y = names(.plot)[3],
-                group = names(.plot)[2],
-                linetype = names(.plot)[2],
-                shape = names(.plot)[2]
+              aes(
+                x = .data[[names(.plot)[1]]],
+                y = .data[[names(.plot)[3]]],
+                group = .data[[names(.plot)[2]]],
+                linetype = .data[[names(.plot)[2]]],
+                shape = .data[[names(.plot)[2]]]
               )
             ) +
               scale_y_continuous(limits = y_limits) +
@@ -368,12 +369,12 @@ create_plotlist <-
           } else {
             p <- ggplot(
               .plot,
-              aes_string(
-                x = names(.plot)[1],
-                y = names(.plot)[3],
-                group = names(.plot)[2],
-                colour = names(.plot)[2],
-                fill = names(.plot)[2]
+              aes(
+                x = .data[[names(.plot)[1]]],
+                y = .data[[names(.plot)[3]]],
+                group = .data[[names(.plot)[2]]],
+                colour = .data[[names(.plot)[2]]],
+                fill = .data[[names(.plot)[2]]]
               )
             ) +
               scale_y_continuous(limits = y_limits) +
@@ -384,15 +385,15 @@ create_plotlist <-
       } else {
         # Single line plot
         if (bw) {
-          p <- ggplot(.plot, aes_string(x = names(.plot)[1],
-                                        y = names(.plot)[2])) +
+          p <- ggplot(.plot, aes(x = .data[[names(.plot)[1]]],
+                                        y = .data[[names(.plot)[2]]])) +
             scale_y_continuous(limits = y_limits) +
             ylab(y_label)
         } else {
           p <- ggplot(.plot,
-                      aes_string(
-                        x = names(.plot)[1],
-                        y = names(.plot)[2],
+                      aes(
+                        x = .data[[names(.plot)[1]]],
+                        y = .data[[names(.plot)[2]]],
                         group = 1,
                         colour = 1,
                         fill = 1
@@ -420,20 +421,18 @@ create_plotlist <-
         if (!cont_mod) {
           # Add shaded confidence ribbon
           if (plot_pi) {
-            p <- p + geom_ribbon(aes_string(ymin = names(.plot)[ncol(.plot) - 2],
-                                            ymax = names(.plot)[ncol(.plot) -
-                                                                  1]),
-                                 alpha = .2)
+            p <- p + geom_ribbon(aes(ymin = .data[[names(.plot)[ncol(.plot) - 2]]],
+                                            ymax = .data[[names(.plot)[ncol(.plot) -1]]]), alpha = .2)
           }
           # Add points
           if (rawdata) {
             p <- p + geom_point(
               data = raw.data,
               alpha = .1,
-              aes_string(
-                x = names(.plot)[1],
-                y = names(raw.data)[1],
-                size = "wi"
+              aes(
+                x = .data[[names(.plot)[1]]],
+                y = .data[[names(raw.data)[1]]],
+                size = .data[["wi"]]
               )
             ) +
               scale_size_continuous(guide = "none")
@@ -449,8 +448,8 @@ create_plotlist <-
           # Add errorbars
           if (plot_pi) {
             p <- p + geom_errorbar(
-              aes_string(ymin = names(.plot)[ncol(.plot) - 2],
-                         ymax =  names(.plot)[ncol(.plot) - 1]),
+              aes(ymin = .data[[names(.plot)[ncol(.plot) - 2]]],
+                         ymax =  .data[[names(.plot)[ncol(.plot) - 1]]]),
               width = .4,
               position = position_dodge(width = .5)
             )
@@ -465,10 +464,10 @@ create_plotlist <-
                 dodge.width = .5
               ),
               alpha = .1,
-              aes_string(
-                x = names(.plot)[1],
-                y = names(raw.data)[1],
-                size = "wi"
+              aes(
+                x = .data[[names(.plot)[1]]],
+                y = .data[[names(raw.data)[1]]],
+                size = .data[["wi"]]
               )
             )
           }
